==> ovirt-engine-3.5.1.1.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/vdsbroker/VmReplicateDiskVDSCommand.java <==
package org.ovirt.engine.core.vdsbroker.vdsbroker;

import java.util.HashMap;
import java.util.Map;

import org.ovirt.engine.core.common.vdscommands.VmReplicateDiskParameters;

public abstract class VmReplicateDiskVDSCommand<P extends VmReplicateDiskParameters> extends VdsBrokerCommand<P> {

    public VmReplicateDiskVDSCommand(P parameters) {
        super(parameters);
    }

    protected Map<String, Object> getDstDiskXmlRpc() {
        Map<String, Object> dstDisk = new HashMap<String, Object>();
        dstDisk.put(VdsProperties.Device, "disk");
        dstDisk.put(VdsProperties.PoolId, getParameters().getStoragePoolId().toString());
        dstDisk.put(VdsProperties.DomainId, getParameters().getTargetStorageDomainId().toString());
        dstDisk.put(VdsProperties.ImageId, getParameters().getImageGroupId().toString());
        dstDisk.put(VdsProperties.VolumeId, getParameters().getImageId().toString());
        return dstDisk;
    }

    protected Map<String, Object> getSrcDiskXmlRpc() {
        Map<String, Object> srcDisk = new HashMap<String, Object>();
        srcDisk.put(VdsProperties.Device, "disk");
        srcDisk.put(VdsProperties.PoolId, getParameters().getStoragePoolId().toString());
        srcDisk.put(VdsProperties.DomainId, getParameters().getSrcStorageDomainId().toString());
        srcDisk.put(VdsProperties.ImageId, getParameters().getImageGroupId().toString());
        srcDisk.put(VdsProperties.VolumeId, getParameters().getImageId().toString());
        return srcDisk;
    }
}

==> ovirt-engine-4.4.8.2.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/vdsbroker/VmReplicateDiskVDSCommand.java <==
package org.ovirt.engine.core.vdsbroker.vdsbroker;

import java.util.HashMap;
import java.util.Map;

import org.ovirt.engine.core.common.vdscommands.VmReplicateDiskParameters;
import org.springframework.util.StringUtils;

public abstract class VmReplicateDiskVDSCommand<P extends VmReplicateDiskParameters> extends VdsBrokerCommand<P> {

    public VmReplicateDiskVDSCommand(P parameters) {
        super(parameters);
    }

    protected Map<String, Object> getDstDisk() {
        Map<String, Object> dstDisk = new HashMap<>();
        dstDisk.put(VdsProperties.Device, "disk");
        dstDisk.put(VdsProperties.PoolId, getParameters().getStoragePoolId().toString());
        dstDisk.put(VdsProperties.DomainId, getParameters().getTargetStorageDomainId().toString());
        dstDisk.put(VdsProperties.ImageId, getParameters().getImageGroupId().toString());
        dstDisk.put(VdsProperties.VolumeId, getParameters().getImageId().toString());
        if (!StringUtils.isEmpty(getParameters().getDiskType())) {
            dstDisk.put(VdsProperties.DiskType, getParameters().getDiskType());
        }
        return dstDisk;
    }

    protected Map<String, Object> getSrcDisk() {
        Map<String, Object> srcDisk = new HashMap<>();
        srcDisk.put(VdsProperties.Device, "disk");
        srcDisk.put(VdsProperties.PoolId, getParameters().getStoragePoolId().toString());
        srcDisk.put(VdsProperties.DomainId, getParameters().getSrcStorageDomainId().toString());
        srcDisk.put(VdsProperties.ImageId, getParameters().getImageGroupId().toString());
        srcDisk.put(VdsProperties.VolumeId, getParameters().getImageId().toString());
        return srcDisk;
    }
}
